********************************************************************************
***																			 ***
** 			Current Account and Real Exchange Rate changes: the				  **
** 						Impact of Trade Openness           					  **
***																			 ***
********************************************************************************
*
** Davide Romelli (Trinity College Dublin)
** Cristina Terra (ESSEC Business School and THEMA)
** Enrico Vasconcelos (Banco Central do Brasil)
*
********************************************************************************
*** This STATA do file contains the codes to replicate all the regressions   ***
*** presented in the paper "Current Account and Real Exchange Rate changes:  ***
*** the	Impact of Trade Openness" 											 ***
********************************************************************************
*
* This version: March 2018
*
********************************************************************************
* TABLE 1 CA & RER (SS using 3y Avg, 2 measures of openness)
********************************************************************************
*
use "Table1", clear
*
* Column 1
reg cagdp openness rer, cluster(ctyid)
* Column 2
reg cagdp openness rer tot wreg imfemerg irr d80 d90, cluster(ctyid)
* Column 3
reg cagdp   opennessrer tot wreg imfemerg irr d80 d90, cluster(ctyid)
* Column 4
reg cagdp openness rer opennessrerdemeaned tot wreg imfemerg irr d80 d90, cluster(ctyid)
* Column 5
reg cagdp  importgdp  rer, cluster(ctyid)
* Column 6
reg cagdp  importgdp  rer tot wreg imfemerg irr d80 d90, cluster(ctyid)
* Column 7
reg cagdp   importgdprer tot wreg imfemerg irr d80 d90, cluster(ctyid)
* Column 8
reg cagdp importgdp rer  importgdprerdemeaned tot wreg imfemerg irr d80 d90, cluster(ctyid)
*
*
********************************************************************************
* TABLE 2 TB & RER (SS using 3y Avg, 2 measures of openness)
********************************************************************************
*
use "Table2", clear
*
* Column 1
reg tbgdp openness rer, cluster(ctyid)
* Column 2
reg tbgdp openness rer tot wreg imfemerg irr d80 d90, cluster(ctyid)
* Column 3
reg tbgdp   opennessrer tot wreg imfemerg irr d80 d90, cluster(ctyid)
* Column 4
reg tbgdp openness rer opennessrerdemeaned tot wreg imfemerg irr d80 d90, cluster(ctyid)
* Column 5
reg tbgdp  importgdp  rer, cluster(ctyid)
* Column 6
reg tbgdp  importgdp  rer tot wreg imfemerg irr d80 d90, cluster(ctyid)
* Column 7
reg tbgdp   importgdprer tot wreg imfemerg irr d80 d90, cluster(ctyid)
* Column 8
reg tbgdp importgdp rer  importgdprerdemeaned tot wreg imfemerg irr d80 d90, cluster(ctyid)
*
*
********************************************************************************
* TABLE 3 CA & RER (RER Depr using 3y Avg, 2 measures of openness)
********************************************************************************
*
use "Table3", clear
*
* Column 1
reg cagdp  openness  rer, cluster(ctyid)
* Column 2
reg cagdp openness  rer tot wreg imfemerg irr d80 d90, cluster(ctyid)
* Column 3
reg cagdp opennessrer tot wreg imfemerg irr d80 d90, cluster(ctyid)
* Column 4
reg cagdp openness  rer opennessrerdemeaned tot wreg imfemerg irr d80 d90, cluster(ctyid)
* Column 5
reg cagdp  importgdp  rer, cluster(ctyid)
* Column 6
reg cagdp  importgdp  rer tot wreg imfemerg irr d80 d90, cluster(ctyid)
* Column 7
reg cagdp  importgdprer tot wreg imfemerg irr d80 d90, cluster(ctyid)
* Column 8
reg cagdp importgdp  rer importgdprerdemeaned tot wreg imfemerg irr d80 d90, cluster(ctyid)
*
*
********************************************************************************
* TABLE 4 TB & RER (RER Depr using 3y Avg, 2 measures of openness)
********************************************************************************
*
use "Table4", clear
*
* Column 1
reg tbgdp  openness  rer, cluster(ctyid)
* Column 2
reg tbgdp openness  rer tot wreg imfemerg irr d80 d90, cluster(ctyid)
* Column 3
reg tbgdp opennessrer tot wreg imfemerg irr d80 d90, cluster(ctyid)
* Column 4
reg tbgdp openness  rer opennessrerdemeaned tot wreg imfemerg irr d80 d90, cluster(ctyid)
* Column 5
reg tbgdp  importgdp  rer, cluster(ctyid)
* Column 6
reg tbgdp  importgdp  rer tot wreg imfemerg irr d80 d90, cluster(ctyid)
* Column 7
reg tbgdp importgdprer tot wreg imfemerg irr d80 d90, cluster(ctyid)
* Column 8
reg tbgdp importgdp  rer importgdprerdemeaned tot wreg imfemerg irr d80 d90, cluster(ctyid)
*
*
********************************************************************************
* TABLE 5 CA, TB RER (SS using 3y Avg, IV measure of openness)
********************************************************************************
*
use "Table5", clear
*
* Column 1
ivreg cagdp (openness = ivopenness) rer, cluster(ctyid)
* Column 2
ivreg cagdp (openness = ivopenness) rer tot wreg imfemerg irr d80 d90, cluster(ctyid)
* Column 3
ivreg cagdp (openness = ivopenness) rer opennessrerdemeaned tot wreg imfemerg irr d80 d90, cluster(ctyid)
* Column 4
ivreg tbgdp (openness = ivopenness) rer, cluster(ctyid)
* Column 5
ivreg tbgdp (openness = ivopenness) rer tot wreg  imfemerg irr d80 d90, cluster(ctyid)
* Column 6
ivreg tbgdp (openness = ivopenness) rer opennessrerdemeanedtb tot wreg  imfemerg irr d80 d90, cluster(ctyid)
*
*
********************************************************************************
* TABLE 6 CA, TB RER (RER Depr using 3y Avg, IV measure of openness)
********************************************************************************
*
use "Table6", clear
*
* Column 1
ivreg cagdp (openness = ivopenness) rer, cluster(ctyid)
* Column 2
ivreg cagdp (openness = ivopenness) rer tot wreg imfemerg irr d80 d90, cluster(ctyid)
* Column 3
ivreg cagdp (openness = ivopenness) rer opennessrerdemeaned tot wreg imfemerg irr d80 d90, cluster(ctyid)
* Column 4
ivreg tbgdp (openness = ivopenness) rer, cluster(ctyid)
* Column 5
ivreg tbgdp (openness = ivopenness) rer tot wreg imfemerg irr  d80 d90, cluster(ctyid)
* Column 6
ivreg tbgdp (openness = ivopenness) rer opennessrerdemeanedtb tot wreg imfemerg irr d80 d90, cluster(ctyid)
*
*
********************************************************************************
* TABLE A2 CA, TB REER (SS using 3y Avg)
********************************************************************************
*
use "TableA2", clear
*
* Column 1
reg cagdp  openness  reer tot wreg imfemerg irr  d80 d90, cluster(ctyid)
* Column 2
reg cagdp openness reer opennessrerdemeaned tot wreg imfemerg irr  d80 d90, cluster(ctyid)
* Column 3
reg cagdp  importgdp  reer tot wreg imfemerg irr  d80 d90, cluster(ctyid)
* Column 4
reg cagdp importgdp reer importgdprerdemeaned tot wreg imfemerg irr  d80 d90, cluster(ctyid)
* Column 5
reg tbgdp openness  reer tot wreg  imfemerg irr  d80 d90, cluster(ctyid)
* Column 6
reg tbgdp openness reer opennessrerdemeanedtb tot wreg imfemerg irr  d80 d90, cluster(ctyid)
* Column 7
reg tbgdp  importgdp  reer tot wreg imfemerg irr d80 d90, cluster(ctyid)
* Column 8
reg tbgdp importgdp reer importgdprerdemeanedtb tot wreg imfemerg irr  d80 d90, cluster(ctyid)
*
*
********************************************************************************
* TABLE A3 CA, TB REER (REER Depr using 3y Avg)
********************************************************************************
*
use "TableA3", clear
*
* Column 1
reg cagdp  openness  reer tot wreg imfemerg irr d80 d90, cluster(ctyid)
* Column 2
reg cagdp openness reer opennessrerdemeaned tot wreg imfemerg irr d80 d90, cluster(ctyid)
* Column 3
reg cagdp  importgdp  reer tot wreg imfemerg irr  d80 d90, cluster(ctyid)
* Column 4
reg cagdp importgdp  reer importgdprerdemeaned tot wreg imfemerg irr d80 d90, cluster(ctyid)
* Column 5
reg tbgdp  openness  reer tot wreg imfemerg irr d80 d90, cluster(ctyid)
* Column 6
reg tbgdp openness  reer opennessrerdemeanedtb tot wreg imfemerg irr d80 d90, cluster(ctyid)
* Column 7
reg tbgdp  importgdp  reer tot wreg imfemerg irr d80 d90, cluster(ctyid)
* Column 8
reg tbgdp importgdp  reer importgdprerdemeanedtb tot wreg imfemerg irr d80 d90, cluster(ctyid)
*
*
********************************************************************************
* TABLE A4 Debt & Original Sin (SS using 3y Avg)
********************************************************************************
*
use "TableA4", clear
*
* Column 1
reg cagdp openness rer opennessrerdemeaned tot wreg imfemerg irr   debtgdp d80 d90, cluster(ctyid)
* Column 2
reg cagdp openness rer opennessrerdemeaned tot wreg imfemerg irr originalsin d80 d90, cluster(ctyid)
* Column 3
* Interaction RER*Emerging Dummy
reg cagdp openness rer opennessrerdemeaned tot wreg imfemerg irr rerimfemerg d80 d90, cluster(ctyid)
* Column 4
* Interaction Openness*RER*Emerging Dummy
reg cagdp openness rer openrerdemean_emerg tot wreg imfemerg irr  d80 d90, cluster(ctyid)
* Column 5
* Episods with Delta Capital Flows <-5%/GDP
reg cagdp openness rer opennessrerdemeaned tot wreg imfemerg irr d80 d90 if dqcf2norm<=-0.00000000005, cluster(ctyid)
* Column 6
* Episodes happening out of crises periods (1997-1999) and (2008-2010)
reg cagdp openness rer opennessrerdemeaned tot wreg imfemerg irr  d80 d90 if quarter!=196 & quarter!=197 & quarter!=198 & quarter!=199 & quarter!=200 & quarter!=201 & quarter!=202 & quarter!=203 & quarter!=148 & quarter!=149 & quarter!=150 & quarter!=151 & quarter!=152 & quarter!=153 & quarter!=154 & quarter!=155 & quarter!=156 & quarter!=157 & quarter!=158 & quarter!=159, cluster(ctyid)
* Column 7
reg cagdp importgdp rer importgdprerdemeaned tot wreg imfemerg irr debtgdp d80 d90, cluster(ctyid)
* Column 8
reg cagdp importgdp rer importgdprerdemeaned tot wreg imfemerg irr  originalsin d80 d90, cluster(ctyid)
* Column 9
* Interaction RER*Emerging Dummy
reg cagdp importgdp rer importgdprerdemeaned tot wreg imfemerg irr rerimfemerg  d80 d90, cluster(ctyid)
* Column 10
* Interaction Openness*RER*Emerging Dummy
reg cagdp importgdp rer impgdprerdem_emerg tot wreg irr imfemerg d80 d90, cluster(ctyid)
* Column 11
* Episods with Delta Capital Flows <-5%/GDP
reg cagdp importgdp rer importgdprerdemeaned tot wreg imfemerg irr d80 d90 if dqcf2norm<=-0.00000000005, cluster(ctyid)
* Column 12
* Episodes happening out of crises periods (1997-1999) and (2008-2010)
reg cagdp importgdp rer importgdprerdemeaned tot wreg imfemerg irr d80 d90 if quarter!=196 & quarter!=197 & quarter!=198 & quarter!=199 & quarter!=200 & quarter!=201 & quarter!=202 & quarter!=203 & quarter!=148 & quarter!=149 & quarter!=150 & quarter!=151 & quarter!=152 & quarter!=153 & quarter!=154 & quarter!=155 & quarter!=156 & quarter!=157 & quarter!=158 & quarter!=159, cluster(ctyid)
*
*
********************************************************************************
* TABLE A5 Debt & Original Sin (RER using 3y Avg)
********************************************************************************
*
use "TableA5", clear
* 
* Column 1
reg cagdp openness rer opennessrerdemeaned tot wreg imfemerg irr   debtgdp d80 d90, cluster(ctyid)
* Column 2
reg cagdp openness rer opennessrerdemeaned tot wreg imfemerg irr originalsin d80 d90, cluster(ctyid)
* Column 3
* Interaction RER*Emerging Dummy
reg cagdp openness rer opennessrerdemeaned tot wreg imfemerg irr rerimfemerg d80 d90, cluster(ctyid)
* Column 4
* Interaction Openness*RER*Emerging Dummy
reg cagdp openness rer openrerdemean_emerg tot wreg imfemerg irr  d80 d90, cluster(ctyid)
* Column 5
* Episodes happening out of crises periods (1997-1999) and (2008-2010)
reg cagdp openness rer opennessrerdemeaned tot wreg imfemerg irr  d80 d90 if quarter!=196 & quarter!=197 & quarter!=198 & quarter!=199 & quarter!=200 & quarter!=201 & quarter!=202 & quarter!=203 & quarter!=148 & quarter!=149 & quarter!=150 & quarter!=151 & quarter!=152 & quarter!=153 & quarter!=154 & quarter!=155 & quarter!=156 & quarter!=157 & quarter!=158 & quarter!=159, cluster(ctyid)
* Column 6
reg cagdp importgdp rer importgdprerdemeaned tot wreg imfemerg irr debtgdp d80 d90, cluster(ctyid)
* Column 7
reg cagdp importgdp rer importgdprerdemeaned tot wreg imfemerg irr  originalsin d80 d90, cluster(ctyid)
* Column 8
* Interaction RER*Emerging Dummy
reg cagdp importgdp rer importgdprerdemeaned tot wreg imfemerg irr rerimfemerg  d80 d90, cluster(ctyid)
* Column 9
* Interaction Openness*RER*Emerging Dummy
reg cagdp importgdp rer impgdprerdem_emerg tot wreg irr imfemerg d80 d90, cluster(ctyid)
* Column 10
* Episodes happening out of crises periods (1997-1999) and (2008-2010)
reg cagdp importgdp rer importgdprerdemeaned tot wreg imfemerg irr d80 d90 if quarter!=196 & quarter!=197 & quarter!=198 & quarter!=199 & quarter!=200 & quarter!=201 & quarter!=202 & quarter!=203 & quarter!=148 & quarter!=149 & quarter!=150 & quarter!=151 & quarter!=152 & quarter!=153 & quarter!=154 & quarter!=155 & quarter!=156 & quarter!=157 & quarter!=158 & quarter!=159, cluster(ctyid)
*
*
